@@ -1,10 +1,20 @@
 data("test_lib")
 
 # Create temp dir for testthat
-tmp <- file.path(tempdir(), "testthat")
+tmp <- file.path(tempdir(), "OpenSpecy-testthat")
 dir.create(tmp, showWarnings = F)
 
+test_that("stop if OSF not reachable", {
+  skip_if_not(is.null(curl::nslookup("api.osf.io", error = F)),
+              message = "OSF is online")
+
+  expect_error(load_lib(which = "test", type = c("metadata", "library"),
+                        path = tmp))
+})
+
 test_that("get_lib() downloads test library", {
+  skip_if_offline(host = "api.osf.io")
+
   expect_message(
     expect_output(get_lib(which = "test", type = c("metadata", "library"),
                           path = tmp))
@@ -12,6 +22,8 @@ test_that("get_lib() downloads test library", {
 })
 
 test_that("check_lib() finds test library", {
+  skip_if_offline(host = "api.osf.io")
+
   expect_silent(check_lib(which = "test", type = c("metadata", "library"),
                           path = tmp))
   expect_warning(check_lib(which = "test", type = c("peaks"),
@@ -19,6 +31,8 @@ test_that("check_lib() finds test library", {
 })
 
 test_that("load_lib() works as expected", {
+  skip_if_offline(host = "api.osf.io")
+
   expect_silent(tl <- load_lib(which = "test", type = c("metadata", "library"),
                                path = tmp))
   expect_type(tl, "list")
